@@ -19,7 +19,7 @@ module Control.Concurrent.Extra(
     -- * Lock
     Lock, newLock, withLock, withLockTry,
     -- * Var
-    Var, newVar, readVar, modifyVar, modifyVar_, withVar,
+    Var, newVar, readVar, writeVar, modifyVar, modifyVar_, withVar,
     -- * Barrier
     Barrier, newBarrier, signalBarrier, waitBarrier, waitBarrierMaybe,
     ) where
@@ -28,6 +28,9 @@ import Control.Concurrent
 import Control.Exception.Extra
 import Control.Monad.Extra
 import Data.Maybe
+import Data.Either.Extra
+import Data.Functor
+import Prelude
 
 
 -- | On GHC 7.6 and above with the @-threaded@ flag, brackets a call to 'setNumCapabilities'.
@@ -133,7 +136,7 @@ newtype Lock = Lock (MVar ())
 
 -- | Create a new 'Lock'.
 newLock :: IO Lock
-newLock = fmap Lock $ newMVar ()
+newLock = Lock <$> newMVar ()
 
 -- | Perform some operation while holding 'Lock'. Will prevent all other
 --   operations from using the 'Lock' while the action is ongoing.
@@ -179,6 +182,10 @@ newVar = fmap Var . newMVar
 readVar :: Var a -> IO a
 readVar (Var x) = readMVar x
 
+-- | Write a value to become the new value of 'Var'.
+writeVar :: Var a -> a -> IO ()
+writeVar v x = modifyVar_ v $ const $ return x
+
 -- | Modify a 'Var' producing a new value and a return result.
 modifyVar :: Var a -> (a -> IO (a, b)) -> IO b
 modifyVar (Var x) f = modifyMVar x f
@@ -220,7 +227,7 @@ newBarrier = fmap Barrier $ newVar . Left =<< newEmptyMVar
 -- | Write a value into the Barrier, releasing anyone at 'waitBarrier'.
 --   Any subsequent attempts to signal the 'Barrier' will throw an exception.
 signalBarrier :: Barrier a -> a -> IO ()
-signalBarrier (Barrier var) v = mask_ $ do -- use mask so never in an inconsistent state
+signalBarrier (Barrier var) v = mask_ $ -- use mask so never in an inconsistent state
     join $ modifyVar var $ \x -> case x of
         Left bar -> return (Right v, putMVar bar ())
         Right res -> error "Control.Concurrent.Extra.signalBarrier, attempt to signal a barrier that has already been signaled"
@@ -237,10 +244,10 @@ waitBarrier (Barrier var) = do
             x <- readVar var
             case x of
                 Right res -> return res
-                Left bar -> error "Cortex.Concurrent.Extra, internal invariant violated in Barrier"
+                Left bar -> error "Control.Concurrent.Extra, internal invariant violated in Barrier"
 
 
 -- | A version of 'waitBarrier' that never blocks, returning 'Nothing'
 --   if the barrier has not yet been signaled.
 waitBarrierMaybe :: Barrier a -> IO (Maybe a)
-waitBarrierMaybe (Barrier bar) = fmap (either (const Nothing) Just) $ readVar bar
+waitBarrierMaybe (Barrier bar) = eitherToMaybe <$> readVar bar
