@@ -7,6 +7,7 @@
 module Control.Exception.Extra(
     module Control.Exception,
     retry, retryBool,
+    errorWithoutStackTrace,
     showException, stringException,
     errorIO, displayException,
     -- * Exception catching/ignoring
@@ -19,6 +20,8 @@ module Control.Exception.Extra(
 import Control.Exception
 import Control.Monad
 import Data.List.Extra
+import Data.Functor
+import Prelude
 
 
 -- | Fully evaluate an input String. If the String contains embedded exceptions it will produce @\<Exception\>@.
@@ -33,7 +36,7 @@ stringException x = do
     case r of
         Left e -> return "<Exception>"
         Right [] -> return []
-        Right (x:xs) -> fmap (x:) $ stringException xs
+        Right (x:xs) -> (x:) <$> stringException xs
 
 
 -- | Show a value, but if the result contains exceptions, produce
@@ -51,6 +54,12 @@ displayException :: Exception e => e -> String
 displayException = show
 #endif
 
+#if __GLASGOW_HASKELL__ < 800
+-- | A variant of 'error' that does not produce a stack trace.
+errorWithoutStackTrace :: String -> a
+errorWithoutStackTrace = error
+#endif
+
 
 -- | Ignore any exceptions thrown by the action.
 --
