@@ -1,4 +1,4 @@
-{-# LANGUAGE CPP, TupleSections #-}
+{-# LANGUAGE CPP, TupleSections, BangPatterns #-}
 {-# OPTIONS_GHC -fno-warn-duplicate-exports #-}
 
 -- | This module extends "Data.List" with extra functions of a similar nature.
@@ -24,16 +24,17 @@ module Data.List.Extra(
     disjoint, allSame, anySame,
     repeatedly, for, firstJust,
     concatUnzip, concatUnzip3,
+    zipFrom, zipWithFrom,
     replace, merge, mergeBy,
     ) where
 
-import Control.Applicative
 import Data.List
 import Data.Maybe
 import Data.Function
 import Data.Char
 import Data.Tuple.Extra
 import Data.Monoid
+import Data.Functor
 import Prelude
 
 
@@ -173,6 +174,25 @@ splitAtEnd i xs = f xs (drop i xs)
           f xs _ = ([], xs)
 
 
+-- | 'zip' against an enumeration.
+--   Never truncates the output - raises an error if the enumeration runs out.
+--
+-- > \i xs -> zip [i..] xs == zipFrom i xs
+-- > zipFrom False [1..3] == undefined
+zipFrom :: Enum a => a -> [b] -> [(a, b)]
+zipFrom = zipWithFrom (,)
+
+-- | 'zipFrom' generalised to any combining operation.
+--
+-- > \i xs -> zipWithFrom (,) i xs == zipFrom i xs
+zipWithFrom :: Enum a => (a -> b -> c) -> a -> [b] -> [c]
+zipWithFrom f a xs = go a xs
+    where
+        -- if we aren't strict in the accumulator, it's highly like to be a space leak
+        go !a [] = []
+        go !a (x:xs) = f a x : go (succ a) xs
+
+
 -- | A merging of 'unzip' and 'concat'.
 --
 -- > concatUnzip [("a","AB"),("bc","C")] == ("abc","ABC")
@@ -490,7 +510,7 @@ dropWhileEnd' p = foldr (\x xs -> if null xs && p x then [] else x : xs) []
 -- > stripSuffix ""    "baz"    == Just "baz"
 -- > stripSuffix "foo" "quux"   == Nothing
 stripSuffix :: Eq a => [a] -> [a] -> Maybe [a]
-stripSuffix a b = fmap reverse $ stripPrefix (reverse a) (reverse b)
+stripSuffix a b = reverse <$> stripPrefix (reverse a) (reverse b)
 
 
 -- | Return the the string before and after the search string,
