@@ -13,6 +13,7 @@ import System.Environment
 #if __GLASGOW_HASKELL__ < 706
 import Control.Exception.Extra
 import System.IO.Error
+import Data.Functor
 
 -- | Alias for 'getProgName' in GHC 7.4 and below, otherwise
 --   returns the absolute pathname of the current executable.
@@ -21,5 +22,5 @@ getExecutablePath = getProgName
 
 -- | Return the value of the environment variable var, or Nothing if there is no such value.
 lookupEnv :: String -> IO (Maybe String)
-lookupEnv x = catchBool isDoesNotExistError (fmap Just $ getEnv x) (const $ return Nothing)
+lookupEnv x = catchBool isDoesNotExistError (Just <$> getEnv x) (const $ return Nothing)
 #endif
