@@ -11,6 +11,8 @@ import Control.Monad
 import System.IO.Extra
 import System.Process
 import System.Exit
+import Data.Functor
+import Prelude
 
 
 -- | A version of 'system' that also captures the output, both 'stdout' and 'stderr'.
@@ -20,7 +22,7 @@ systemOutput x = withTempFile $ \file -> do
     exit <- withFile file WriteMode $ \h -> do
         (_, _, _, pid) <- createProcess (shell x){std_out=UseHandle h, std_err=UseHandle h}
         waitForProcess pid
-    fmap (exit,) $ readFile' file
+    (exit,) <$> readFile' file
 
 
 -- | A version of 'system' that throws an error if the 'ExitCode' is not 'ExitSuccess'.
