@@ -47,14 +47,16 @@ testRaw msg test = do
     modifyIORef testCount (+1)
 
 
-erroneous :: a -> Bool
-erroneous x = unsafePerformIO $ fmap isLeft $ try_ $ evaluate x
+erroneous :: Show a => a -> Bool
+erroneous x = unsafePerformIO $ fmap isLeft $ try_ $ evaluate $ length $ show x
 
-erroneousIO :: IO a -> Bool
-erroneousIO x = unsafePerformIO $ fmap isLeft $ try_ $ evaluate =<< x
+erroneousIO :: Show a => IO a -> Bool
+erroneousIO x = unsafePerformIO $ fmap isLeft $ try_ $ evaluate . length . show =<< x
 
 (====) :: (Show a, Eq a) => a -> a -> Bool
-a ==== b = if a == b then True else error $ "Not equal!\n" ++ show a ++ "\n" ++ show b
+a ==== b
+    | a == b = True
+    | otherwise = error $ "Not equal!\n" ++ show a ++ "\n" ++ show b
 
 #if __GLASGOW_HASKELL__ < 707
 instance Eq ErrorCall where
@@ -70,11 +72,9 @@ runTests t = do
 
 instance Testable () where
     property = property . (`seq` True)
-    exhaustive _ = True
 
 instance Testable a => Testable (IO a) where
     property = property . unsafePerformIO
-    exhaustive = exhaustive . unsafePerformIO
 
 instance Eq a => Eq (IO a) where
     a == b = unsafePerformIO $ do
@@ -103,7 +103,4 @@ instance Arbitrary Day where
     arbitrary = fmap ModifiedJulianDay arbitrary
 
 instance Arbitrary DiffTime where
-    arbitrary = fmap realToFrac $ choose (0 :: Double, 86401)
-
-instance Arbitrary Version where
-    arbitrary = makeVersion . map abs <$> listOf1 arbitrary
+    arbitrary = realToFrac <$> choose (0 :: Double, 86401)
